From ba1e1ccf869b818f7a7a897264dfea05563a7796 Mon Sep 17 00:00:00 2001
From: Jake Vanderwerf <get@jakevanderwerf.ca>
Date: Sun, 07 Jun 2026 20:10:20 +0000
Subject: [PATCH] =Major overhaul of Integrations. Playing around with adding fields to post types through Registrar from an integrations' class file.

---
 cleanup.php |   48 +++++++++++++++++++++++++++++++++++++++++++++++-
 1 files changed, 47 insertions(+), 1 deletions(-)

diff --git a/cleanup.php b/cleanup.php
index 461c845..8aef5fa 100644
--- a/cleanup.php
+++ b/cleanup.php
@@ -34,6 +34,7 @@
 		'wp-block-library',
 		'wp-block-library-theme',
 		'wp-block-styles',
+		'block-style-variation-styles'
 	];
 
 	foreach ($global_styles as $style) {
@@ -210,7 +211,7 @@
 		BASE . 'gallery'
 	];
 
 	//TODO: Dynamically use MetaManager to get any image or gallery fields
 	foreach ($meta_fields as $meta_key) {
 		$meta_value = get_post_meta($post_id, $meta_key, true);
 
@@ -263,3 +264,48 @@
 	return $clean_classes;
 }
 add_filter('body_class', 'jvbBodyClasses');
+
+
+add_action('admin_init', function () {
+	// Redirect any user trying to access comments page
+	global $pagenow;
+
+	if ($pagenow === 'edit-comments.php') {
+		wp_redirect(admin_url());
+		exit;
+	}
+
+	// Remove comments metabox from dashboard
+	remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
+
+	// Disable support for comments and trackbacks in post types
+	foreach (get_post_types() as $post_type) {
+		if (post_type_supports($post_type, 'comments')) {
+			remove_post_type_support($post_type, 'comments');
+			remove_post_type_support($post_type, 'trackbacks');
+		}
+	}
+});
+
+// Close comments on the front-end
+add_filter('comments_open', '__return_false', 20, 2);
+add_filter('pings_open', '__return_false', 20, 2);
+
+// Hide existing comments
+add_filter('comments_array', '__return_empty_array', 10, 2);
+
+// Remove comments page in menu
+add_action('admin_menu', function () {
+	remove_menu_page('edit-comments.php');
+});
+
+// Remove comments links from admin bar
+add_action('init', function () {
+	if (is_admin_bar_showing()) {
+		remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
+	}
+});
+// Remove comments links from admin bar
+add_action('add_admin_bar_menus', function () {
+	remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
+});
@@ -210,7 +211,7 @@
 	];
 
-	//TODO: Dynamically use MetaManager to get any image or gallery fields
+	//TODO: Dynamically use Meta.php to get any image or gallery fields
 	foreach ($meta_fields as $meta_key) {
 		$meta_value = get_post_meta($post_id, $meta_key, true);

--
Gitblit v1.10.0